@@ -15,7 +15,7 @@ require 'ctioga2/utils'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 223 $', '$Date: 2011-01-11 01:07:48 +0100 (Tue, 11 Jan 2011) $')
+  Version::register_svn_info('$Revision: 517 $', '$Date: 2013-09-19 18:28:15 +0200 (Thu, 19 Sep 2013) $')
 
   module Commands
  
@@ -48,6 +48,36 @@ EOD
 
     FloatType = CmdType.new('float', :float, <<EOD)
 A floating-point number.
+EOD
+
+    FloatOrFalseType = CmdType.new('float-or-false', {
+                              :type => :float,
+                              :shortcuts => {'none' => false }}, 
+                              <<EOD)
+A floating-point number, or @none@.
+EOD
+
+
+    FloatList = CmdType.new('float-list', 
+                            {
+                              :type => :array,
+                              :subtype => :float,
+                              :separator => /\s+|\s*,\s*/,
+                              :separator_out => " "
+                            }, <<EOD)
+A list of space-separated or comma-separated floating point numbers.
+EOD
+
+    TextList = CmdType.new('text-list', 
+                            {
+                              :type => :array,
+                              :subtype => :string,
+                              :separator => /\s*,\s*/,
+                              :alternative_separator => /\s*\|\|\s*/,
+                              :separator_out => ","
+                            }, <<EOD)
+A list of comma-separated texts. If you must include a comma inside the
+texts, then use @||@ as a separator.
 EOD
 
     IntegerType = CmdType.new('integer', :integer, <<EOD)
