@@ -25,7 +25,7 @@ require 'stringio'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 372 $', '$Date: 2012-12-28 18:13:15 +0100 (Fri, 28 Dec 2012) $')
+  Version::register_svn_info('$Revision: 524 $', '$Date: 2013-09-22 16:18:39 +0200 (Sun, 22 Sep 2013) $')
 
 
   module Data
@@ -150,7 +150,12 @@ EOD
             end
             return ret
           else
-            return super
+            m = Dir::glob(spec)
+            if m.size > 0
+              return m
+            else
+              return super
+            end
           end
         end
 
@@ -183,10 +188,8 @@ EOD
                 return IO.popen(method % file)
               end
             end
-            return File::open(file)
           end
-          error { "Could not open #{file}" }
-          return nil
+          return File::open(file)
         end
 
         # A line is invalid if it is blank or starts
@@ -382,7 +385,11 @@ EOD
                                            @current_data,
                                            @included_modules)
           else
-            return @current_data[column.to_i].dup
+            if @current_data[column.to_i]
+              return @current_data[column.to_i].dup
+            else
+              raise "Cannot find column number #{column.to_i} -- maybe you got the column separator wrong ?"
+            end
           end
         end
 
@@ -427,6 +434,7 @@ EOD
 #         end
 
       end
+
       
     end
 
