@@ -18,7 +18,7 @@ require 'ctioga2/data/indexed-dtable'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 406 $', '$Date: 2013-08-22 21:23:44 +0200 (Thu, 22 Aug 2013) $')
+  Version::register_svn_info('$Revision: 451 $', '$Date: 2013-08-29 01:28:30 +0200 (Thu, 29 Aug 2013) $')
 
 
   # \todo now, port the backend infrastructure...
@@ -87,7 +87,7 @@ module CTioga2
       def self.dataset_from_spec(name, spec)
         specs = []
         i = 0
-        for s in spec.split(/:/)
+        for s in spec.split_at_toplevel(/:/)
           if s =~ /^(x|y\d*|z)(#{DataColumn::ColumnSpecsRE})=(.*)/i
             which, mod, s = $1.downcase,($2 && $2.downcase) || "value",$3
             
