@@ -25,7 +25,7 @@ require 'ctioga2/data/filters'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 390 $', '$Date: 2013-03-13 11:36:47 +0100 (Wed, 13 Mar 2013) $')
+  Version::register_svn_info('$Revision: 518 $', '$Date: 2013-09-19 21:43:58 +0200 (Thu, 19 Sep 2013) $')
 
 
   module Data
@@ -72,6 +72,20 @@ module CTioga2
 
         # Defaults to the 'text' backend
         @backend_factory = Data::Backends::BackendFactory.new('text')
+
+        # Probably a bit out of place...
+        csv = 
+          Cmd.new('csv', nil, '--csv', []) do |plotmaker|
+          plotmaker.interpreter.
+            run_commands("text /separator=/[,;]/")
+        end
+        
+        csv.describe("reads CSV files", 
+                            <<"EOH", "backend-text")
+Now parse the following data files as CSV.
+
+# text /separator=/[,;]/
+EOH
       end
 
       # Performs expansion on the given _set_ with the current
@@ -547,7 +561,8 @@ EOH
 Adds the given commands to the dataset hook. See {command: dataset-hook} 
 for more information about the dataset hook.
 EOH
-
+  
+  
   end
 
 end
