@@ -19,7 +19,7 @@ require 'Dobjects/Function'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 300 $', '$Date: 2011-06-07 21:17:49 +0200 (Tue, 07 Jun 2011) $')
+  Version::register_svn_info('$Revision: 535 $', '$Date: 2013-10-02 20:31:21 +0200 (Wed, 02 Oct 2013) $')
 
   module Graphics
 
@@ -40,35 +40,28 @@ module CTioga2
       # factory, I think. Color maps can be used for colors, but for
       # the rest, things will have to be implemented as parameters to
       # the curve generator, or even separated commands.
-      class Parametric2D  < TiogaElement
+      class Parametric2D  < PlotBasedElement
 
         include Log
         include Dobjects
 
-        # The Data::Dataset object that should get plotted.
-        attr_accessor :dataset
-
-        # A Styles::CurveStyle object saying how the curve should be
-        # drawn.
-        #
-        # Some of the elements will be overridden.
-        attr_accessor :curve_style
-
         # For convenience only: xy functions
         attr_accessor :function
 
         # A hash Z value -> corresponding XY functions.
         attr_accessor :planes
 
+        # A ParametricPlotStyle object handling the correspondance
+        # between Z axis and stylistic aspects
+        attr_accessor :parametric_style
 
-
-        undef :location=, :location
-        
         # Creates a new Curve2D object with the given _dataset_ and
         # _style_.
-        def initialize(dataset, style = nil)
+        def initialize(dataset, style = nil, parametric_plot_style = nil)
           @dataset = dataset
           @curve_style = style
+          
+          @parametric_style = parametric_plot_style
           prepare_data
         end
 
@@ -84,22 +77,26 @@ module CTioga2
             @planes[zs[0]].x << x
             @planes[zs[0]].y << y
           end
+
+          
+          @zmin = []
+          @zmax = []
+
+          ## @todo This should rather use Z axes in the end ?
+          (@dataset.ys.size - 1).times do |i|
+            @zmin << @dataset.ys[i+1].values.min
+            @zmax << @dataset.ys[i+1].values.max
+          end
         end
         
         protected :prepare_data
 
-        # Returns the LocationStyle object of the curve. Returns the
-        # one from #curve_style.
-        def location
-          return @curve_style.location
-        end
-
         # Returns the Types::Boundaries of this curve.
         def get_boundaries
           return Types::Boundaries.bounds(@function.x, @function.y)
         end
 
-        # Draws the markers, if applicable.
+        # Draws the path lines, if applicable.
         def draw_path(t)
           min = @dataset.z.values.min
           max = @dataset.z.values.max
@@ -125,19 +122,16 @@ module CTioga2
 
         # Draws the markers, if applicable.
         def draw_markers(t)
-          min = @dataset.z.values.min
-          max = @dataset.z.values.max
+          @parametric_style.prepare
           if @curve_style.has_marker?
             # We use a default color map for the markers
             @curve_style.marker_color_map ||= 
               Styles::ColorMap.from_text("Red--Green")
-            cmap = @curve_style.marker_color_map
-            for zs in @planes.keys.sort ## \todo have the sort
-                                        ## direction configurable.
-              f = @planes[zs]
-              color = cmap.z_color(zs, min, max)
-              @curve_style.marker.draw_markers_at(t, f.x, f.y, 
-                                                  { 'color' => color})
+
+            @dataset.each_values do |i,x,y,*z|
+              ms = @parametric_style.marker_style(@curve_style, 
+                                                  z, @zmin, @zmax)
+              ms.draw_markers_at(t, x, y)
             end
           end
         end
