@@ -22,7 +22,7 @@ require 'shellwords'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 391 $', '$Date: 2013-03-14 11:04:36 +0100 (Thu, 14 Mar 2013) $')
+  Version::register_svn_info('$Revision: 531 $', '$Date: 2013-09-29 00:07:44 +0200 (Sun, 29 Sep 2013) $')
 
   module Graphics
 
@@ -83,6 +83,22 @@ module CTioga2
           @options = options
         end
 
+        undef :clipped, :clipped=
+
+        def clipped
+          if @options.key? 'clipped'
+            return @options['clipped']
+          else
+            return true         # Defaults to clipped
+          end
+        end
+
+        undef :depth, :depth=
+          
+        def depth
+          @options['depth'] || 50
+        end
+
         @known_primitives = {}
 
         PrimitiveCommands = {}
@@ -111,7 +127,9 @@ module CTioga2
                             CmdArg.new(v)
                           end
           end
-          
+
+          cmd_opts['clipped'] = CmdArg.new('boolean')
+          cmd_opts['depth'] = CmdArg.new('integer')
           cmd = Cmd.new("draw-#{name}",nil,"--draw-#{name}", 
                         cmd_args, cmd_opts) do |plotmaker, *rest|
             options = rest.pop
