@@ -16,7 +16,7 @@ require 'ctioga2/log'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 329 $', '$Date: 2012-12-11 00:13:17 +0100 (Tue, 11 Dec 2012) $')
+  Version::register_svn_info('$Revision: 540 $', '$Date: 2013-10-04 00:05:23 +0200 (Fri, 04 Oct 2013) $')
 
   module Graphics
 
@@ -132,6 +132,24 @@ module CTioga2
         end
 
 
+        def clip_and_plot(t, elements)
+          clusters = Utils::cluster_by_value(elements, :clipped)
+          
+          for clst in clusters
+            t.context do
+              if clst[0].clipped
+                t.clip_to_frame
+              end
+              for element in clst 
+                t.context do 
+                  t.set_bounds(get_el_boundaries(element).to_a)
+                  element.do(t)
+                end
+              end
+            end
+          end
+        end
+
 
         # Plots all the objects inside the plot.
         def real_do(t)
@@ -151,24 +169,44 @@ module CTioga2
             # Manually creating the plot:
             t.set_bounds(real_boundaries.to_a)
 
+            # First, gather up all elements by depth
+
+            els_by_depth = Utils::sort_by_value(@elements, :depth)
+
+            background = []
+            mid = []
+            fore = []
+
+            # Organize by depth
+            for depth in els_by_depth.keys.sort.reverse
+              v = els_by_depth[depth]
+              if depth && (depth >= 90)
+                background += v
+              elsif depth && depth <= 10
+                fore += v
+              else
+                mid += v
+              end
+            end
+
             # Drawing the background elements:
+
+            clip_and_plot(t, background)
+
             t.context do
               t.clip_to_frame
 
               @style.background.draw_background(t)
 
               @style.draw_all_background_lines(t)
-              i = 0
-              for element in @elements 
-                t.context do 
-                  t.set_bounds(get_el_boundaries(element).to_a)
-                  element.do(t)
-                end
-                i += 1
-              end
             end
+
+            clip_and_plot(t, mid)
+
             @style.draw_all_axes(t, @computed_boundaries)
 
+            clip_and_plot(t, fore)
+
             # Now drawing legends:
             if @legend_area
               a, b = @legend_area.partition_frame(t, self)
