@@ -17,7 +17,7 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 377 $', '$Date: 2013-02-01 12:10:20 +0100 (Fri, 01 Feb 2013) $')
+  Version::register_svn_info('$Revision: 540 $', '$Date: 2013-10-04 00:05:23 +0200 (Fri, 04 Oct 2013) $')
 
   module Graphics
 
@@ -255,7 +255,7 @@ module CTioga2
               if last_value + 1 < i
                 (last_value+1).upto(i - 1) do |j|
                   frac = (j - last_value)/(i - last_value + 1.0)
-                  p [last_value, j, i, frac]
+                  # p [last_value, j, i, frac]
                   z_values[j] = z_values[last_value] * frac + 
                     z_values[i] * (1 - frac)
                 end
