@@ -17,7 +17,7 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 416 $', '$Date: 2013-08-23 00:35:49 +0200 (Fri, 23 Aug 2013) $')
+  Version::register_svn_info('$Revision: 531 $', '$Date: 2013-09-29 00:07:44 +0200 (Sun, 29 Sep 2013) $')
 
   module Graphics
 
@@ -52,6 +52,12 @@ module CTioga2
         # the filled region.
         typed_attribute :region_position, "region-side"
 
+        # Wether that element is clipped or not.
+        typed_attribute :clipped, 'boolean'
+
+        # The depth. 
+        typed_attribute :depth, 'integer'
+
         # A path style.
         #
         # @todo Ideas for a path style include
@@ -79,6 +85,11 @@ module CTioga2
         # A colormap for markers (only for XYZ data) 
         typed_attribute :marker_color_map, 'colormap'
 
+        # If this is specified when choosing the marker scale as a
+        # function of a given Z value, then the original Z segment is
+        # mapped to min_scale -> scale.
+        typed_attribute :marker_min_scale, 'float-or-false'
+
         # Whether the XY display should split on NaN values (wherever)
         typed_attribute :split_on_nan, 'boolean'
 
@@ -92,6 +103,11 @@ module CTioga2
         # Generator#curve_from_dataset
         attr_accessor :target
 
+        def initialize()
+          @clipped = true
+          @depth = 50
+        end
+
         # True if a line should be drawn.
         def has_line?
           return @line && @line.style
