@@ -17,7 +17,7 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 419 $', '$Date: 2013-08-23 01:05:42 +0200 (Fri, 23 Aug 2013) $')
+  Version::register_svn_info('$Revision: 466 $', '$Date: 2013-08-31 13:10:38 +0200 (Sat, 31 Aug 2013) $')
 
   module Graphics
 
@@ -154,11 +154,7 @@ module CTioga2
       # how the fill should be applied to curves.
       class CurveFillStyle < FillStyle
 
-        # At which Y value we should draw the horizontal line for the
-        # fill ? A float, or:
-        # * :top, :bottom
-        # * false, nil to disable filling altogether
-        typed_attribute :y0, 'fill-until'
+        typed_attribute :close_type, 'fill-until'
         
       end
 
