@@ -17,7 +17,7 @@ require 'ctioga2/log'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 432 $', '$Date: 2013-08-23 19:06:36 +0200 (Fri, 23 Aug 2013) $')
+  Version::register_svn_info('$Revision: 531 $', '$Date: 2013-09-29 00:07:44 +0200 (Sun, 29 Sep 2013) $')
 
   module Graphics
 
@@ -105,16 +105,10 @@ module CTioga2
 
 
         # Creates a new parameter for the style factory.
-        #
-        # \todo add a way to add some more text to the description;
-        # possibly a self.describe_parameter function ?
-        #
-        # @todo Remove completely the 'type' argument
         def self.define_parameter(target, name, sets, description, 
                                   short_option = nil, disable_cmds = false)
           # We define two new types:
           # - first, the color-or-auto type:
-          # base_type = Commands::CommandType.get_type(type)
           base_type = CurveStyle.attribute_type(target)
 
           if ! Commands::Interpreter.type("#{base_type.name}-or-auto")
@@ -251,7 +245,9 @@ module CTioga2
           @override_parameters = {
             'line_style' => LineStyles::Solid,
             'marker_marker' => false,
-            'marker_scale' => 0.5 
+            'marker_scale' => 0.5,
+            'fill_color' => '=color'.to_sym,
+            'error_bar_color' => '=marker_color'.to_sym
           }
           @parameters_carrays = {}
           for target, param in self.class.parameters
@@ -341,6 +337,8 @@ module CTioga2
 
         simple_parameter 'marker_scale', "marker scale", Sets::LineWidthSets
 
+        simple_parameter 'marker_min_scale', "marker scale", nil
+
         # Error bars:
         simple_parameter 'error_bar_color', "error bar color", 
         Sets::ColorSets
@@ -353,11 +351,15 @@ module CTioga2
         nil, "Y axis", nil, true
 
         # Now, fill style
-        define_parameter 'fill_y0', 'fill', 
+        define_parameter 'fill_close_type', 'fill', 
         {}, "Fill until", nil
 
         simple_parameter 'fill_color', "fill color", Sets::ColorSets
 
+        simple_parameter 'clipped', "clipped", nil
+
+        simple_parameter 'depth', "depth", nil
+
         simple_parameter 'fill_transparency', 'fill transparency', {}
 
         # Region handling
@@ -454,6 +456,9 @@ module CTioga2
             for k,v in h
               v.to_s =~ /^(?:=|->)(\S+)/
               target = $1
+              if CurveStyleFactory.name_to_target[target]
+                target = CurveStyleFactory.name_to_target[target]
+              end
               if tv.key? target
                 tv[k] = tv[target]
                 h.delete(k)
