@@ -17,6 +17,7 @@ require 'ctioga2/graphics/types/boundaries'
 require 'ctioga2/graphics/types/boxes'
 require 'ctioga2/graphics/types/bijection'
 require 'ctioga2/graphics/types/location'
+require 'ctioga2/graphics/types/fill'
 
 
 require 'ctioga2/graphics/types/grid'
@@ -25,7 +26,7 @@ require 'ctioga2/graphics/types/grid'
 # This module contains all the classes used by ctioga
 module CTioga2
 
-  Version::register_svn_info('$Revision: 376 $', '$Date: 2013-01-23 22:52:47 +0100 (Wed, 23 Jan 2013) $')
+  Version::register_svn_info('$Revision: 523 $', '$Date: 2013-09-22 15:31:16 +0200 (Sun, 22 Sep 2013) $')
 
   module Graphics
 
@@ -48,6 +49,7 @@ module CTioga2
 
     ColorType = CmdType.new('color', {
                               :type => :tioga_color,
+                              :namespace => Tioga::ColorConstants,
                             }, <<EOD)
 A color. It can take three forms:
  * a named color, see 
@@ -60,27 +62,12 @@ EOD
     ColorOrFalseType = 
       CmdType.new('color-or-false', {
                     :type => :tioga_color,
+                    :namespace => Tioga::ColorConstants,
                     :shortcuts => {'none' => false }
                   }, <<EOD)
-A {type: color}, or false to say that nothing should be drawn.
+A {type: color}, or none to say that nothing should be drawn.
 EOD
 
-    CurveFillUntilType = CmdType.new('fill-until', {
-                                       :type => :float,
-                                       :shortcuts => {
-                                         /x?axis/i => 0.0,
-                                         /b(?:ot(?:tom)?)?/i => :bottom,
-                                         /t(?:op)?/i => :top,
-                                         /no(?:ne)?/i => false
-                                       }
-                                     }, <<EOD)
-The Y values until which a filled curve will be filled. Generally a number, 
-but it can also be:
- * @axis@ (or @xaxis@), which means 0
- * @bottom@, to fill until the bottom of the graph
- * @top@, to fill until the top 
- * @none@, meaning no fill
-EOD
 
     RegionSideType = 
       CmdType.new('region-side', {
