@@ -20,7 +20,7 @@ require 'ctioga2/utils'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 401 $', '$Date: 2013-08-19 17:29:59 +0200 (Mon, 19 Aug 2013) $')
+  Version::register_svn_info('$Revision: 484 $', '$Date: 2013-09-02 22:44:42 +0200 (Mon, 02 Sep 2013) $')
 
 
   module MetaBuilder
@@ -149,8 +149,9 @@ module CTioga2
           # We make a copy for our own purposes.
           subtype = type[:subtype] || {:type => :string}
           @subtype = Type.get_type(subtype)
-          @separator = /\s*,\s*/
-          @separator_out = ','
+          @separator = type[:separator] || /\s*,\s*/
+          @alternative_separator = type[:alternative_separator] || nil
+          @separator_out = type[:separator_out] || ','
         end
 
         def type_name
@@ -158,7 +159,11 @@ module CTioga2
         end
 
         def string_to_type_internal(str)
-          ary = str.split(@separator)
+          if @alternative_separator && str =~ @alternative_separator
+            ary = str.split(@alternative_separator)
+          else
+            ary = str.split(@separator)
+          end
           return ary.map do |a|
             @subtype.string_to_type(a)
           end
@@ -167,6 +172,7 @@ module CTioga2
         def type_to_string_internal(val)
           return val.map do |a|
             @subtype.type_to_string(a)
+            # Won't alway work !
           end.join(@separator_out)
         end
       end
