@@ -20,7 +20,7 @@ require 'ctioga2/utils'
 
 module CTioga2
 
-  Version::register_svn_info('$Revision: 351 $', '$Date: 2012-12-25 22:48:10 +0100 (Tue, 25 Dec 2012) $')
+  Version::register_svn_info('$Revision: 401 $', '$Date: 2013-08-19 17:29:59 +0200 (Mon, 19 Aug 2013) $')
 
   module MetaBuilder
     module Types
@@ -159,7 +159,7 @@ module CTioga2
                 return v
             end
           end
-          raise IncorrectInput, "Not an axis type: #{str}"
+          raise IncorrectInput, "Not an axis type: '#{str}'"
         end
       end
 
