@@ -106,6 +106,9 @@ CTioga2::Log::init_logger
 
 require 'shellwords'
 
+# Path name mangling
+require 'pathname'
+
 # Maybe, maybe, maybe... We need tioga ?
 require 'Tioga/FigureMaker'
 
@@ -155,7 +158,7 @@ require 'ctioga2/postprocess'
 # displays of rate constants vs potentials)
 module CTioga2
 
-  Version::register_svn_info('$Revision: 431 $', '$Date: 2013-08-23 17:58:47 +0200 (Fri, 23 Aug 2013) $')
+  Version::register_svn_info('$Revision: 522 $', '$Date: 2013-09-22 12:02:48 +0200 (Sun, 22 Sep 2013) $')
 
   # This class is the core of ctioga. It parses the command-line arguments,
   # reads all necessary files and plots graphs. Most of its functionality
@@ -201,6 +204,9 @@ module CTioga2
     # Additional preamble for LaTeX output
     attr_accessor :latex_preamble
 
+    # Global font information
+    attr_accessor :latex_font
+
     # What happens to generated PDF files (a PostProcess object)
     attr_accessor :postprocess
 
@@ -241,6 +247,10 @@ module CTioga2
       # Original preamble
       @latex_preamble = ""
 
+      @latex_font = Graphics::Styles::FullLatexFont.new
+
+      @latex_font.size = 15
+
       @postprocess = PostProcess.new
 
       # Make sure it is registered
@@ -333,40 +343,52 @@ module CTioga2
       
       info { "Producing figure '#{figname}'" }
 
+
       t = create_figure_maker
-      # If figname is clearly a path, we split it into directory/name
-      # and set the output directory to directory.
-      if File::basename(figname) != figname
-        dir = File::dirname(figname)
-        # If path is relative and output_directory is specified, we make
-        # the path relative to output_dir
-        if @output_directory && dir =~ /^[^\/~]/
-          dir = File::join(@output_directory, dir)
+
+      path = Pathname.new(figname)
+      if @output_directory
+        out = Pathname.new(@output_directory)
+        path = out + path
+      end
+
+      # We always cd into the target directory for creading the
+      Dir.chdir(path.dirname) do
+        fn = path.basename.to_s
+
+        efn = fn.gsub(/[.\s]/) do |x|
+          "__#{x.ord}__"
         end
-        t.save_dir = dir
-        figname = File::basename(figname)
-      elsif @output_directory
-        t.save_dir = @output_directory
-      end
 
-      t.def_figure(figname) do
-        @root_object.draw_root_object(t)
-      end
-      t.make_preview_pdf(t.figure_index(figname))
+        if efn != fn
+          debug { "Mangled name to '#{fn}'"}
+        end
 
-      # We look for latex errors
-      if t.respond_to? :pdflatex_errors
-        errs = t.pdflatex_errors
-        if errs.size > 0
-          error { "pdflatex returned with #{errs.size} error lines"}
-          for l in errs
-            warn { "pdflatex error: #{l.chomp}" }
+        t.def_figure(efn) do
+          @latex_font.set_global_font(t)
+          @root_object.draw_root_object(t)
+        end
+        t.make_preview_pdf(t.figure_index(efn))
+
+        # We look for latex errors
+        if t.respond_to? :pdflatex_errors
+          errs = t.pdflatex_errors
+          if errs.size > 0
+            error { "pdflatex returned with #{errs.size} error lines"}
+            for l in errs
+              warn { "pdflatex error: #{l.chomp}" }
+            end
           end
         end
+
+        # We first rename the PDF file if it was mangled.
+        if efn != fn
+          File::rename("#{efn}.pdf", "#{fn}.pdf")
+        end
+
       end
 
-      file = t.save_dir ? File::join(t.save_dir, figname + ".pdf") : 
-        figname + ".pdf"
+      file = path.to_s + ".pdf"
 
       # Feed it
       @postprocess.process_file(file, last)
@@ -440,6 +462,7 @@ module CTioga2
       # applicable.
       t.tex_preamble += 
         "\n\\pdfinfo {\n#{title}/Creator(#{Utils::pdftex_quote_string("ctioga2 #{Version::version}")})\n}\n"
+
       return t
     end
 
@@ -542,6 +565,18 @@ the command {command: preamble} with the argument:
 
 @ \\usepackage[utf8]{inputenc}\\usepackage[T1]{fontenc}
 
+EOD
+
+    LatexFontCommand = 
+      Cmd.new("set-global-font",nil,"--set-global-font", 
+              [], Graphics::Styles::FullLatexFont.options_hash) do |plotmaker, opts|
+      plotmaker.latex_font.set_from_hash(opts)
+    end
+
+    LatexFontCommand.describe('Set global font details',
+                              <<EOD, LaTeXGroup)
+Set global font. Sets the size of everything, including that of text
+that has already been used.
 EOD
 
 
@@ -665,12 +700,18 @@ EOH
     
     XpdfViewerCommand = 
       Cmd.new("xpdf",'-X',"--xpdf", [ ]) do |plotmaker|
-      plotmaker.postprocess.viewer = "xpdf -z page"
+      plotmaker.postprocess.viewer = :auto
     end
 
     XpdfViewerCommand.describe('Uses xpdf to view the produced PDF files', 
                               <<EOH, OutputSetupGroup)
 Uses xpdf to view the PDF files produced by ctioga2.
+
+If xpdf is not found, then it tries to guess which viewers are available:
+ * on windows, it uses the system file associations to open the PDF file
+ * on mac, it uses the open command
+ * on linux, it tries, mime-open, and if that is missing, falls back to
+   commonly available PDF viewers.
 EOH
 
     OpenViewerCommand = 
